@@ -2,16 +2,13 @@
 Implementation of hooks and APIs for outputting log messages.
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sys
 import traceback
 import inspect
 import json as pyjson
 from threading import Lock
 from functools import wraps
-
-from six import text_type as unicode, PY3
+from io import IOBase
 
 from pyrsistent import PClass, field
 
@@ -19,12 +16,7 @@ from . import _bytesjson as bytesjson
 from zope.interface import Interface, implementer
 
 from ._traceback import write_traceback, TRACEBACK_MESSAGE
-from ._message import (
-    Message,
-    EXCEPTION_FIELD,
-    MESSAGE_TYPE_FIELD,
-    REASON_FIELD,
-)
+from ._message import Message, EXCEPTION_FIELD, MESSAGE_TYPE_FIELD, REASON_FIELD
 from ._util import saferepr, safeunicode
 from .json import EliotJSONEncoder
 from ._validation import ValidationError
@@ -161,6 +153,7 @@ class Logger(object):
     whose messages you want to unit test in isolation, e.g. a class. The tests
     can then replace a specific L{Logger} with a L{MemoryLogger}.
     """
+
     _destinations = Destinations()
 
     def _safeUnicodeDictionary(self, dictionary):
@@ -176,7 +169,7 @@ class Logger(object):
             faithfully as can be done without putting in too much effort.
         """
         try:
-            return unicode(
+            return str(
                 dict(
                     (saferepr(key), saferepr(value))
                     for (key, value) in dictionary.items()
@@ -198,7 +191,7 @@ class Logger(object):
             msg = Message(
                 {
                     MESSAGE_TYPE_FIELD: "eliot:serialization_failure",
-                    "message": self._safeUnicodeDictionary(dictionary)
+                    "message": self._safeUnicodeDictionary(dictionary),
                 }
             )
             msg.write(self)
@@ -215,14 +208,12 @@ class Logger(object):
                     # construct a message.
                     msg = Message(
                         {
-                            MESSAGE_TYPE_FIELD:
-                            "eliot:destination_failure",
-                            REASON_FIELD:
-                            safeunicode(exception),
-                            EXCEPTION_FIELD:
-                            exc_type.__module__ + "." + exc_type.__name__,
-                            "message":
-                            self._safeUnicodeDictionary(dictionary)
+                            MESSAGE_TYPE_FIELD: "eliot:destination_failure",
+                            REASON_FIELD: safeunicode(exception),
+                            EXCEPTION_FIELD: exc_type.__module__
+                            + "."
+                            + exc_type.__name__,
+                            "message": self._safeUnicodeDictionary(dictionary),
                         }
                     )
                     self._destinations.send(msg._freeze())
@@ -238,10 +229,12 @@ def exclusively(f):
     Decorate a function to make it thread-safe by serializing invocations
     using a per-instance lock.
     """
+
     @wraps(f)
     def exclusively_f(self, *a, **kw):
         with self._lock:
             return f(self, *a, **kw)
+
     return exclusively_f
 
 
@@ -307,15 +300,13 @@ class MemoryLogger(object):
         except Exception as e:
             # Skip irrelevant frames that don't help pinpoint the problem:
             from . import _output, _message, _action
-            skip_filenames = [
-                _output.__file__, _message.__file__, _action.__file__
-            ]
+
+            skip_filenames = [_output.__file__, _message.__file__, _action.__file__]
             for frame in inspect.stack():
                 if frame[1] not in skip_filenames:
                     break
             self._failed_validations.append(
-                "{}: {}".format(
-                    e, "".join(traceback.format_stack(frame[0])))
+                "{}: {}".format(e, "".join(traceback.format_stack(frame[0])))
             )
         self.messages.append(dictionary)
         self.serializers.append(serializer)
@@ -341,13 +332,11 @@ class MemoryLogger(object):
         if serializer is not None:
             serializer.validate(dictionary)
         for key in dictionary:
-            if not isinstance(key, unicode):
+            if not isinstance(key, str):
                 if isinstance(key, bytes):
                     key.decode("utf-8")
                 else:
-                    raise TypeError(
-                        dictionary, "%r is not unicode" % (key, )
-                    )
+                    raise TypeError(dictionary, "%r is not unicode" % (key,))
         if serializer is not None:
             serializer.serialize(dictionary)
 
@@ -355,8 +344,7 @@ class MemoryLogger(object):
             bytesjson.dumps(dictionary)
             pyjson.dumps(dictionary)
         except Exception as e:
-            raise TypeError("Message %s doesn't encode to JSON: %s" % (
-                dictionary, e))
+            raise TypeError("Message %s doesn't encode to JSON: %s" % (dictionary, e))
 
     @exclusively
     def validate(self):
@@ -384,7 +372,6 @@ class MemoryLogger(object):
                 # raise.
                 raise e.__class__("\n\n".join(self._failed_validations))
 
-
     @exclusively
     def serialize(self):
         """
@@ -417,6 +404,7 @@ class MemoryLogger(object):
         self.tracebackMessages = []
         self._failed_validations = []
 
+
 class FileDestination(PClass):
     """
     Callable that writes JSON messages to a file.
@@ -431,41 +419,38 @@ class FileDestination(PClass):
 
     @ivar _linebreak: C{"\n"} as either bytes or unicode.
     """
+
     file = field(mandatory=True)
     encoder = field(mandatory=True)
     _dumps = field(mandatory=True)
     _linebreak = field(mandatory=True)
 
     def __new__(cls, file, encoder=EliotJSONEncoder):
+        if isinstance(file, IOBase) and not file.writable():
+            raise RuntimeError("Given file {} is not writeable.")
+
         unicodeFile = False
-        if PY3:
-            try:
-                file.write(b"")
-            except TypeError:
-                unicodeFile = True
+        try:
+            file.write(b"")
+        except TypeError:
+            unicodeFile = True
 
         if unicodeFile:
             # On Python 3 native json module outputs unicode:
             _dumps = pyjson.dumps
-            _linebreak = u"\n"
+            _linebreak = "\n"
         else:
             _dumps = bytesjson.dumps
             _linebreak = b"\n"
         return PClass.__new__(
-            cls,
-            file=file,
-            _dumps=_dumps,
-            _linebreak=_linebreak,
-            encoder=encoder
+            cls, file=file, _dumps=_dumps, _linebreak=_linebreak, encoder=encoder
         )
 
     def __call__(self, message):
         """
         @param message: A message dictionary.
         """
-        self.file.write(
-            self._dumps(message, cls=self.encoder) + self._linebreak
-        )
+        self.file.write(self._dumps(message, cls=self.encoder) + self._linebreak)
         self.file.flush()
 
 
@@ -475,9 +460,7 @@ def to_file(output_file, encoder=EliotJSONEncoder):
 
     @param output_file: A file-like object.
     """
-    Logger._destinations.add(
-        FileDestination(file=output_file, encoder=encoder)
-    )
+    Logger._destinations.add(FileDestination(file=output_file, encoder=encoder))
 
 
 # The default Logger, used when none is specified:
